@@ -6,7 +6,7 @@ from django.core.serializers.json import DjangoJSONEncoder
 
 class MomoPayProcessor:
     
-    def __init__(self, data=None, merchant={}, callback=None, *args, **kwargs):
+    def __init__(self, data=None, merchant=None, callback=None, *args, **kwargs):
 
         if data is not None:
             self.user = data['user']
@@ -20,28 +20,30 @@ class MomoPayProcessor:
         if callback is not None:
             self.callback = callback
         
-        self.merchantID = merchant.get('id', settings.PAYMENT_MERCHANT)
-        self.merchant_username = merchant.get('username', settings.PAYMENT_USERNAME)
-        self.merchant_password = merchant.get('password', settings.PAYMENT_PASSWORD)
+        self.merchant = merchant
 
     def pay(self):
-
-        self.getPaymentPayload()
-        
-        self.momotrans = MomoTransaction.objects.create(
-            user = self.user,
-            amount = self.amount,
-            network = self.network,
-            msisdn = self.momo_number,
-            info_sent = self.payload,
-            order_id = self.orderID,
-            merchant_id = self.merchantID,
-            merchant_name = self.merchant_username,
-        )
-        self.response = requests.post(settings.PAYMENT_GATEWAY, data=json.dumps(self.payload, cls=DjangoJSONEncoder))
-        self.momotrans.initial_callback = self.response.text
-        self.momotrans.save()
-        self.parseMomoResponse()
+        set_merchant = self.setMerchant()
+        if set_merchant['status']:
+            self.getPaymentPayload()
+            try:
+                self.momotrans = MomoTransaction.objects.create(
+                    user = self.user,
+                    amount = self.amount,
+                    network = self.network,
+                    msisdn = self.momo_number,
+                    info_sent = self.payload,
+                    order_id = self.orderID,
+                    merchant_id = self.merchantID,
+                    merchant_name = self.merchant_username,
+                )
+            except Exception as e:
+                return {"status":False, "message":f"{e}"}
+            self.response = requests.post(settings.PAYMENT_GATEWAY, data=json.dumps(self.payload, cls=DjangoJSONEncoder))
+            self.momotrans.initial_callback = self.response.text
+            self.momotrans.save()
+            self.parseMomoResponse()
+        return set_merchant
 
         
 
@@ -58,13 +60,28 @@ class MomoPayProcessor:
             self.momotrans.final_callback = response.text
             
         except Exception as e:
-            # print(e)
             self.momotrans.final_callback = f"{e}"
         
         self.momotrans.status = StatusTypes.FAILED
         self.momotrans.save()
         return {"status": False, "message":"Failed"}
 
+    
+    def setMerchant(self):
+
+        if self.merchant is not None:
+            self.merchantID = merchant.get('id')
+            self.merchant_username = merchant.get('username')
+            self.merchant_password = merchant.get('password')
+        else:
+            try:
+                self.merchantID = settings.PAYMENT_MERCHANT
+                self.merchant_username = settings.PAYMENT_USERNAME
+                self.merchant_password = settings.PAYMENT_PASSWORD
+            except Exception as e:
+                return {"status":False, "message":f"{e}"}
+        return {"status":True}
+
 
     
     def generateOrderID(self):
